import * as solid_js from 'solid-js';
import { JSXElement } from 'solid-js';
import { Ref } from '@solid-primitives/refs';
import { ChartTypeRegistry, ChartData, ChartOptions, Plugin } from 'chart.js';

/**
 * Chart props
 */
interface ChartProps {
    /**
     * Chart.js chart type
     */
    type: keyof ChartTypeRegistry;
    /**
     * The data object that is passed into the Chart.js chart
     * @see https://www.chartjs.org/docs/latest/getting-started/
     */
    data?: ChartData;
    /**
     * The options object that is passed into the Chart.js chart
     * @see https://www.chartjs.org/docs/latest/general/options.html
     * @default {}
     */
    options?: ChartOptions;
    /**
     * The plugins array that is passed into the Chart.js chart
     * @see https://www.chartjs.org/docs/latest/developers/plugins.html
     * @default []
     */
    plugins?: Plugin[];
    /**
     * The width of the canvas element
     * @default 512
     */
    width?: number | undefined;
    /**
     * The height of the canvas element
     * @default 512
     */
    height?: number | undefined;
    /**
     * The fallback element to render when the canvas cannot be rendered.
     * @default null
     */
    fallback?: JSXElement | null;
    /**
     * Support for any other Chart.js options
     * @default {}
     */
    [key: string]: any;
    /**
     * A ref to the Chart.js instance
     * @default null
     */
    ref?: Ref<HTMLCanvasElement | null>;
}

declare function DefaultChart(props: ChartProps): solid_js.JSX.Element;

type TypedChartProps = Omit<ChartProps, 'type'>;
declare const Line: (props: TypedChartProps) => solid_js.JSX.Element;
declare const Bar: (props: TypedChartProps) => solid_js.JSX.Element;
declare const Radar: (props: TypedChartProps) => solid_js.JSX.Element;
declare const Doughnut: (props: TypedChartProps) => solid_js.JSX.Element;
declare const PolarArea: (props: TypedChartProps) => solid_js.JSX.Element;
declare const Bubble: (props: TypedChartProps) => solid_js.JSX.Element;
declare const Pie: (props: TypedChartProps) => solid_js.JSX.Element;
declare const Scatter: (props: TypedChartProps) => solid_js.JSX.Element;

export { Bar, Bubble, ChartProps, DefaultChart, Doughnut, Line, Pie, PolarArea, Radar, Scatter, TypedChartProps };
